==> core_models-0.1.0.gem: app/controllers/core_models/base/genders_controller.rb <==
require_dependency "core_models/core_models_controller"

module CoreModels
  class Base::GendersController < CoreModelsController
    # GET /base/genders
    # GET /base/genders.json
    def index
      @base_genders = Base::Gender.all

      respond_to do |format|
        format.html # index.html.erb
        format.json { render :json => @base_genders }
      end
    end

    # GET /base/genders/1
    # GET /base/genders/1.json
    def show
      @base_gender = Base::Gender.find(params[:id])

      respond_to do |format|
        format.html # show.html.erb
        format.json { render :json => @base_gender }
      end
    end

    # GET /base/genders/new
    # GET /base/genders/new.json
    def new
      @base_gender = Base::Gender.new

      respond_to do |format|
        format.html # new.html.erb
        format.json { render :json => @base_gender }
      end
    end

    # GET /base/genders/1/edit
    def edit
      @base_gender = Base::Gender.find(params[:id])
    end

    # POST /base/genders
    # POST /base/genders.json
    def create
      @base_gender = Base::Gender.new(params[:base_gender])

      respond_to do |format|
        if @base_gender.save
          format.html { redirect_to @base_gender, :notice => 'Gender was successfully created.' }
          format.json { render :json => @base_gender, :status => :created, :location => @base_gender }
        else
          format.html { render :action => "new" }
          format.json { render :json => @base_gender.errors, :status => :unprocessable_entity }
        end
      end
    end

    # PUT /base/genders/1
    # PUT /base/genders/1.json
    def update
      @base_gender = Base::Gender.find(params[:id])

      respond_to do |format|
        if @base_gender.update_attributes(params[:base_gender])
          format.html { redirect_to @base_gender, :notice => 'Gender was successfully updated.' }
          format.json { head :no_content }
        else
          format.html { render :action => "edit" }
          format.json { render :json => @base_gender.errors, :status => :unprocessable_entity }
        end
      end
    end

    # DELETE /base/genders/1
    # DELETE /base/genders/1.json
    def destroy
      @base_gender = Base::Gender.find(params[:id])
      @base_gender.destroy

      respond_to do |format|
        format.html { redirect_to base_genders_url }
        format.json { head :no_content }
      end
    end
  end
end

==> core_models-0.2.9.gem: app/controllers/core_models/base/genders_controller.rb <==
require_dependency "core_models/core_models_controller"

module CoreModels
  class Base::GendersController < CoreModelsController
    # GET /base/genders
    # GET /base/genders.json
    def index
      @base_genders = Base::Gender.all

      respond_to do |format|
        format.html # index.html.erb
        format.json { render :json => @base_genders }
      end
    end

    # GET /base/genders/1
    # GET /base/genders/1.json
    def show
      @base_gender = Base::Gender.find(params[:id])

      respond_to do |format|
        format.html # show.html.erb
        format.json { render :json => @base_gender }
      end
    end

    # GET /base/genders/new
    # GET /base/genders/new.json
    def new
      @base_gender = Base::Gender.new

      respond_to do |format|
        format.html # new.html.erb
        format.json { render :json => @base_gender }
      end
    end

    # GET /base/genders/1/edit
    def edit
      @base_gender = Base::Gender.find(params[:id])
    end

    # POST /base/genders
    # POST /base/genders.json
    def create
      @base_gender = Base::Gender.new(params[:base_gender])

      respond_to do |format|
        if @base_gender.save
          format.html { redirect_to @base_gender, :notice => 'Gender was successfully created.' }
          format.json { render :json => @base_gender, :status => :created, :location => @base_gender }
        else
          format.html { render :action => "new" }
          format.json { render :json => @base_gender.errors, :status => :unprocessable_entity }
        end
      end
    end

    # PUT /base/genders/1
    # PUT /base/genders/1.json
    def update
      @base_gender = Base::Gender.find(params[:id])

      respond_to do |format|
        if @base_gender.update(params[:base_gender])
          format.html { redirect_to @base_gender, :notice => 'Gender was successfully updated.' }
          format.json { head :no_content }
        else
          format.html { render :action => "edit" }
          format.json { render :json => @base_gender.errors, :status => :unprocessable_entity }
        end
      end
    end

    # DELETE /base/genders/1
    # DELETE /base/genders/1.json
    def destroy
      @base_gender = Base::Gender.find(params[:id])
      @base_gender.destroy

      respond_to do |format|
        format.html { redirect_to base_genders_url }
        format.json { head :no_content }
      end
    end
  end
end
